==> cvsync-0.24.13.tar.gz: cvsync-0.24.13/common/mdirent.h <==
/*-
 * Copyright (c) 2000-2003 MAEKAWA Masahide <maekawa@cvsync.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef __MDIRENT_H__
#define	__MDIRENT_H__

#include "basedef.h"

struct mDIR {
	void		*m_entries;
	size_t		m_nentries, m_offset;

	void		*m_parent;
	size_t		m_parent_pathlen;
};

struct mdirent {
	char		md_name[CVSYNC_NAME_MAX + 1];
	size_t		md_namelen;
	struct stat	md_stat;
	boolean		md_dead;
};

struct mdirent_rcs {
	char		md_name[CVSYNC_NAME_MAX + 1];
	size_t		md_namelen;
	struct stat	md_stat;
	boolean		md_dead;

	/* rcs specific */
	boolean		md_attic;
};

struct mdirent_args {
	int		mda_errormode;
	boolean		mda_symfollow, mda_remove;
};

void mclosedir(struct mDIR *);
int malphasort(const void *, const void *);

struct mDIR *mopendir_rcs(char *, size_t, size_t, struct mdirent_args *);

#endif /* __MDIRENT_H__ */

==> cvsync-0.24.18.tar.gz: cvsync-0.24.18/common/mdirent.h <==
/*-
 * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef __MDIRENT_H__
#define	__MDIRENT_H__

struct mDIR {
	void		*m_entries;
	size_t		m_nentries, m_offset;

	void		*m_parent;
	size_t		m_parent_pathlen;
};

struct mdirent {
	char		md_name[CVSYNC_NAME_MAX + 1];
	size_t		md_namelen;
	struct stat	md_stat;
	bool		md_dead;
};

struct mdirent_rcs {
	char		md_name[CVSYNC_NAME_MAX + 1];
	size_t		md_namelen;
	struct stat	md_stat;
	bool		md_dead;

	/* rcs specific */
	bool		md_attic;
};

struct mdirent_args {
	int		mda_errormode;
	bool		mda_symfollow, mda_remove;
};

void mclosedir(struct mDIR *);
int malphasort(const void *, const void *);

struct mDIR *mopendir_rcs(char *, size_t, size_t, struct mdirent_args *);

#endif /* __MDIRENT_H__ */
